gpkg_contentsGet a vector of grid, feature and attribute table names registered in GeoPackage.
gpkg_list_contents(x, ogr = FALSE)character. Vector of grid, feature and attribute table names registered in GeoPackage.
A geopackage object, path to a GeoPackage or an SQLiteConnection
Intersect gpkg_contents table name result with OGR tables that are listed in gpkg_ogr_contents? Default: FALSE
gpkg_contents() gpkg_list_tables()